@@ -463,16 +463,14 @@ plotAsso <- function(jointModelResult,type){
     adj <- jointModelResult$adjPearson
     unadj <- jointModelResult$Pearson
     
-    qplot(unadj, adj, ylab = "Adjusted Association", xlab = "Unadjusted Association",
-          main = "Pearson")
+    qplot(unadj, adj, ylab = "Adjusted Association(Pearson)", xlab = "Unadjusted Association(Pearson)") 
     
   } else if(type == "Spearman") {
     
     adj <- jointModelResult$adjSpearman
     unadj <- jointModelResult$Spearman
     
-    qplot(unadj, adj, ylab = "Adjusted Association", xlab = "Unadjusted Association",
-          main = "Spearman")
+    qplot(unadj, adj, ylab = "Adjusted Association(Spearman)", xlab = "Unadjusted Association(Spearman)")
   } else {
     stop("Please specify Pearson or Spearman")
   }
@@ -597,7 +595,9 @@ plot1gene <- function(geneName,fp,fpName = "",responseVector,dat,resPlot=TRUE,co
         facet_grid(.~fpId, scales="free")+
         geom_point(aes(fill=factor(fp)),size=8, shape=21) +
         scale_fill_manual("FP:",values = c("0" = colA,"1" = colP),labels=c("0 - absent", "1 - present"))+
-        ggtitle(paste("Unadj. Asso.",UnadjPearson))+
+        ggtitle(paste("Unadj. Asso.",UnadjPearson))+ 
+		theme(axis.text.x = element_text( hjust=0, vjust=1),
+          plot.title = element_text(size = 20, face = "bold", colour = "black", vjust = -2,hjust = 0.5)) +
         geom_smooth(method = lm)+
         theme(strip.text.x = element_text(face="bold",size=14))
       
@@ -607,7 +607,9 @@ plot1gene <- function(geneName,fp,fpName = "",responseVector,dat,resPlot=TRUE,co
         facet_grid(.~fpId, scales="free")+
         geom_point(aes(fill=factor(fp)),size=8, shape=21) +
         scale_fill_manual("FP:",values = c("0" = colA,"1" = colP),labels=c("0 - absent", "1 - present"))+
-        ggtitle(paste("Adj. Asso.",AdjPearson))+
+        ggtitle(paste("Adj. Asso.",AdjPearson))+ 
+		theme(axis.text.x = element_text( hjust=0, vjust=1),
+          plot.title = element_text(size = 20, face = "bold", colour = "black", vjust = -2,hjust = 0.5)) +
         geom_smooth(method = lm)+
         theme(strip.text.x = element_text(face="bold",size=14))
       
